# Table of Contents

- [advanced-use-cases-for-integration-api](<./advanced-use-cases-for-integration-api.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Advanced Use Cases for the Integration API](<./Advanced-Use-Cases-for-the-Integration-API.md>)
  - [Field and Value Processing](<./Advanced-Use-Cases-for-the-Integration-API/Field-and-Value-Processing.md>)
  - [JUEL and RegEx](<./Advanced-Use-Cases-for-the-Integration-API/JUEL-and-RegEx.md>)
  - [RegEx and JUEL](<./Advanced-Use-Cases-for-the-Integration-API/RegEx-and-JUEL.md>)
  - [Advanced JUEL](<./Advanced-Use-Cases-for-the-Integration-API/Advanced-JUEL.md>)
  - [JUEL Use Cases](<./Advanced-Use-Cases-for-the-Integration-API/JUEL-Use-Cases.md>)
  - [Best Name for Fact Sheet](<./Advanced-Use-Cases-for-the-Integration-API/Best-Name-for-Fact-Sheet.md>)
  - [Using "Integration" Object](<./Advanced-Use-Cases-for-the-Integration-API/Using-Integration-Object.md>)
  - [Calculating with single-select fields](<./Advanced-Use-Cases-for-the-Integration-API/Calculating-with-single-select-fields.md>)
  - [Updating multi_select fields from an array](<./Advanced-Use-Cases-for-the-Integration-API/Updating-multi_select-fields-from-an-array.md>)
  - [Remove content from fields](<./Advanced-Use-Cases-for-the-Integration-API/Remove-content-from-fields.md>)
  - [Write-back to Fact Sheet](<./Advanced-Use-Cases-for-the-Integration-API/Write-back-to-Fact-Sheet.md>)
  - [Dynamic definition of Fact Sheet fields to read](<./Advanced-Use-Cases-for-the-Integration-API/Dynamic-definition-of-Fact-Sheet-fields-to-read.md>)
  - [Auto deletion with inboundProcessors](<./Advanced-Use-Cases-for-the-Integration-API/Auto-deletion-with-inboundProcessors.md>)
  - [Remove tags](<./Advanced-Use-Cases-for-the-Integration-API/Remove-tags.md>)
  - [Preventing removal of items](<./Advanced-Use-Cases-for-the-Integration-API/Preventing-removal-of-items.md>)
  - [Advanced deletion](<./Advanced-Use-Cases-for-the-Integration-API/Advanced-deletion.md>)
  - [Deletion for multiple external sources](<./Advanced-Use-Cases-for-the-Integration-API/Deletion-for-multiple-external-sources.md>)
  - [Delete tags of multiple groups](<./Advanced-Use-Cases-for-the-Integration-API/Delete-tags-of-multiple-groups.md>)
  - [Deletion of Subscriptions](<./Advanced-Use-Cases-for-the-Integration-API/Deletion-of-Subscriptions.md>)
  - [Data exchange and Aggregation between Objects](<./Advanced-Use-Cases-for-the-Integration-API/Data-exchange-and-Aggregation-between-Objects.md>)
  - [Writing Variables using Expressions](<./Advanced-Use-Cases-for-the-Integration-API/Writing-Variables-using-Expressions.md>)
  - [Dynamic Variable Handling](<./Advanced-Use-Cases-for-the-Integration-API/Dynamic-Variable-Handling.md>)
  - [Supported Dynamic Variable Operations](<./Advanced-Use-Cases-for-the-Integration-API/Supported-Dynamic-Variable-Operations.md>)
  - [forEach Logic](<./Advanced-Use-Cases-for-the-Integration-API/forEach-Logic.md>)
  - [Example: forEach](<./Advanced-Use-Cases-for-the-Integration-API/Example-forEach.md>)
  - [Example: Nested forEach](<./Advanced-Use-Cases-for-the-Integration-API/Example-Nested-forEach.md>)
  - [Example: forEach to update dynamic fields](<./Advanced-Use-Cases-for-the-Integration-API/Example-forEach-to-update-dynamic-fields.md>)
  - [Use "object" key to output all objects](<./Advanced-Use-Cases-for-the-Integration-API/Use-object-key-to-output-all-objects.md>)
  - [Filter Processor execution based on current Fact Sheet content](<./Advanced-Use-Cases-for-the-Integration-API/Filter-Processor-execution-based-on-current-Fact-Sheet-content.md>)
  - [Load large LDIFs](<./Advanced-Use-Cases-for-the-Integration-API/Load-large-LDIFs.md>)
  - [Long running API calls](<./Advanced-Use-Cases-for-the-Integration-API/Long-running-API-calls.md>)
  - [Executing Processor Configurations with Custom Technical Users](<./Advanced-Use-Cases-for-the-Integration-API/Executing-Processor-Configurations-with-Custom-Technical-Users.md>)
  - [Restricting the Execution of Processor Configurations](<./Advanced-Use-Cases-for-the-Integration-API/Restricting-the-Execution-of-Processor-Configurations.md>)
  - [Search Based Matching of Fact Sheets](<./Advanced-Use-Cases-for-the-Integration-API/Search-Based-Matching-of-Fact-Sheets.md>)
  - [Include Archived Fact Sheets in scope result](<./Advanced-Use-Cases-for-the-Integration-API/Include-Archived-Fact-Sheets-in-scope-result.md>)
  - [Bookmarks to define search scope](<./Advanced-Use-Cases-for-the-Integration-API/Bookmarks-to-define-search-scope.md>)
  - [Read-Only FactSheet Processor](<./Advanced-Use-Cases-for-the-Integration-API/Read-Only-FactSheet-Processor.md>)
  - [Accessing the "Hierarchy Level" of a Fact Sheet](<./Advanced-Use-Cases-for-the-Integration-API/Accessing-the-Hierarchy-Level-of-a-Fact-Sheet.md>)
  - [Was this page helpful?](<./Advanced-Use-Cases-for-the-Integration-API/Was-this-page-helpful.md>)
